@@ -11,6 +11,8 @@
 #' @param scaled logical If \code{TRUE} relative units are assumed.
 #' @param normalized logical (\code{FALSE}) or numeric Normalization wavelength
 #'   in manometers (nm).
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #'
 #' @return a character string or an R expression.
 #'
@@ -27,12 +29,21 @@ counts_label <- function(unit.exponent = 3,
                                             default = "R.expression"),
                          label.text = axis_labels()[["counts"]],
                          scaled = FALSE,
-                         normalized = FALSE) {
+                         normalized = FALSE,
+                         axis.symbols = getOption("ggspectra.axis.symbols",
+                                                 default = TRUE)) {
+  if (!axis.symbols) {
+    label.text <- gsub(",$", "", label.text)
+  }
   if (scaled) {
     if (tolower(format) == "latex") {
       paste(label.text, "$N_{\\lambda}$ (rel.\ units)")
     } else if (format == "R.expression") {
-      bquote(.(label.text)~italic(N)[lambda]~plain((rel.~units)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(N)[lambda]~plain((rel.~units)))
+      } else {
+        bquote(.(label.text)~plain((rel.~units)))
+      }
     } else if (format == "R.character") {
       "Pixel response N(lambda) (rel. units)"
     }
@@ -40,7 +51,11 @@ counts_label <- function(unit.exponent = 3,
     if (tolower(format) == "latex") {
       paste(label.text, " $N_{\\lambda} / N_{", normalized, "}$ (/1)", sep = "")
     } else if (format == "R.expression") {
-      bquote(plain(Pixel~~response)~italic(N)[lambda]/italic(N)[.(normalized)]~plain("(/1)"))
+      if (axis.symbols) {
+        bquote(plain(Pixel~~response)~italic(N)[lambda]/italic(N)[.(normalized)]~plain("(/1)"))
+      } else {
+        bquote(plain(Pixel~~response)*", normalised"~plain("(/1)"))
+      }
     } else if (format == "R.character") {
       paste(label.text, "N(lambda) (norm. at", normalized, "nm)")
     }
@@ -55,9 +70,17 @@ counts_label <- function(unit.exponent = 3,
       }
     } else if (format %in% c("R.expression")) {
       if (unit.exponent == 0) {
-        bquote(.(label.text)~italic(N)[lambda]~(counts))
+        if (axis.symbols) {
+          bquote(.(label.text)~italic(N)[lambda]~(counts))
+        } else {
+          bquote(.(label.text)~(counts))
+        }
       } else {
-        bquote(.(label.text)~italic(N)[lambda]~(10^{.(unit.exponent)}*plain(counts)))
+        if (axis.symbols) {
+          bquote(.(label.text)~italic(N)[lambda]~(10^{.(unit.exponent)}*plain(counts)))
+        } else {
+          bquote(.(label.text)~(10^{.(unit.exponent)}*plain(counts)))
+        }
       }
     } else if (format == "R.character" && unit.exponent == 0) {
       paste(label.text, "N(lambda) (counts)")
@@ -82,6 +105,8 @@ counts_label <- function(unit.exponent = 3,
 #' @param scaled logical If \code{TRUE} relative units are assumed.
 #' @param normalized logical (\code{FALSE}) or numeric Normalization wavelength
 #'   in manometers (nm).
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #' @param ... other named arguments passed to \code{scale_y_continuous}
 #'
 #' @note This function only alters default arguments values for \code{name} and
@@ -130,13 +155,16 @@ scale_y_counts_continuous <-
                                format = format,
                                label.text = label.text,
                                scaled = scaled,
-                               normalized = round(normalized, 1)),
+                               normalized = round(normalized, 1),
+                               axis.symbols = axis.symbols),
            labels = SI_pl_format(exponent = unit.exponent),
            format = getOption("photobiology.math",
                               default = "R.expression"),
            label.text = axis_labels()[["counts"]],
            scaled = FALSE,
            normalized = FALSE,
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_y_continuous(name = name,
                        labels = labels,
@@ -153,13 +181,16 @@ scale_y_counts_tg_continuous <-
                                format = format,
                                label.text = label.text,
                                scaled = scaled,
-                               normalized = round(normalized, 1)),
+                               normalized = round(normalized, 1),
+                               axis.symbols = axis.symbols),
            labels = SI_tg_format(exponent = unit.exponent),
            format = getOption("photobiology.math",
                               default = "R.expression"),
            label.text = axis_labels()[["counts"]],
            scaled = FALSE,
            normalized = FALSE,
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_y_continuous(name = name,
                        labels = labels,
