@@ -60,6 +60,8 @@ w_frequency <- photobiology::wl2frequency
 #' @param format character string, "R", "R.expresion", "R.character", or
 #'   "LaTeX".
 #' @param label.text character Textual portion of the labels.
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #'
 #' @return a character string or an R expression.
 #'
@@ -68,19 +70,25 @@ w_frequency <- photobiology::wl2frequency
 #' @examples
 #'
 #' w_length_label()
-#' w_length_label("R.expression")
-#' w_length_label("LaTeX")
+#' w_length_label(axis.symbols = FALSE)
+#' w_length_label(format = "R.expression")
+#' w_length_label(format = "LaTeX")
 #' w_number_label()
-#' w_number_label("R.expression")
+#' w_number_label(format = "R.expression")
 #' w_frequency_label()
-#' w_frequency_label("R.expression")
+#' w_frequency_label(format = "R.expression")
 #' w_energy_J_label()
 #' w_energy_eV_label()
 #'
 w_length_label <- function(unit.exponent = -9,
                            format = getOption("photobiology.math",
                                               default = "R.expression"),
-                           label.text = axis_labels()[["w.length"]]) {
+                           label.text = axis_labels()[["w.length"]],
+                           axis.symbols = getOption("ggspectra.axis.symbols",
+                                                   default = TRUE)) {
+  if (!axis.symbols) {
+    label.text <- gsub(",$", "", label.text)
+  }
   if (tolower(format) == "latex") {
     if (has_SI_prefix(unit.exponent)) {
       paste(label.text, " $\\lambda$ (",
@@ -94,9 +102,17 @@ w_length_label <- function(unit.exponent = -9,
   } else if (format %in% c("R.expression")) {
     if (has_SI_prefix(unit.exponent)) {
       prefix <- exponent2prefix(unit.exponent)
-      bquote(.(label.text)~lambda~(plain(.(prefix))*plain(m)))
+      if (axis.symbols) {
+        bquote(.(label.text)~lambda~(plain(.(prefix))*plain(m)))
+      } else {
+        bquote(.(label.text)~(plain(.(prefix))*plain(m)))
+      }
     } else {
-      bquote(.(label.text)~lambda~(10^{.(unit.exponent)}~plain(m)))
+      if (axis.symbols) {
+        bquote(.(label.text)~lambda~(10^{.(unit.exponent)}~plain(m)))
+      } else {
+        bquote(.(label.text)~(10^{.(unit.exponent)}~plain(m)))
+      }
     }
   } else if (format == "R.character" &&
              has_SI_prefix(unit.exponent)) {
@@ -116,7 +132,12 @@ w_length_label <- function(unit.exponent = -9,
 w_number_label <- function(unit.exponent = 0,
                            format = getOption("photobiology.math",
                                               default = "R.expression"),
-                           label.text = axis_labels()[["w.number"]]) {
+                           label.text = axis_labels()[["w.number"]],
+                           axis.symbols = getOption("ggspectra.axis.symbols",
+                                                   default = TRUE)) {
+  if (!axis.symbols) {
+    label.text <- gsub(",$", "", label.text)
+  }
   if (tolower(format) == "latex") {
     if (has_SI_prefix(unit.exponent)) {
       paste(label.text, " $\\nu$ (",
@@ -130,9 +151,17 @@ w_number_label <- function(unit.exponent = 0,
   } else if (format %in% c("R.expression")) {
     if (has_SI_prefix(unit.exponent)) {
       prefix <- exponent2prefix(unit.exponent)
-      bquote(.(label.text)~nu~(plain(.(prefix))*plain(m)^{-1}))
+      if (axis.symbols) {
+        bquote(.(label.text)~nu~(plain(.(prefix))*plain(m)^{-1}))
+      } else {
+        bquote(.(label.text)~(plain(.(prefix))*plain(m)^{-1}))
+      }
     } else {
-      bquote(.(label.text)~nu~(10^{.(unit.exponent)}~plain(m)^{-1}))
+      if (axis.symbols) {
+        bquote(.(label.text)~nu~(10^{.(unit.exponent)}~plain(m)^{-1}))
+      } else {
+        bquote(.(label.text)~(10^{.(unit.exponent)}~plain(m)^{-1}))
+      }
     }
   } else if (format == "R.character" &&
              has_SI_prefix(unit.exponent)) {
@@ -153,7 +182,12 @@ w_number_label <- function(unit.exponent = 0,
 w_frequency_label <- function(unit.exponent = 9,
                               format = getOption("photobiology.math",
                                                  default = "R.expression"),
-                              label.text = axis_labels()[["freq"]]) {
+                              label.text = axis_labels()[["freq"]],
+                              axis.symbols = getOption("ggspectra.axis.symbols",
+                                                      default = TRUE)) {
+  if (!axis.symbols) {
+    label.text <- gsub(",$", "", label.text)
+  }
   if (tolower(format) == "latex") {
     if (has_SI_prefix(unit.exponent)) {
       paste(label.text, " $f$ (",
@@ -167,9 +201,17 @@ w_frequency_label <- function(unit.exponent = 9,
   } else if (format %in% c("R.expression")) {
     if (has_SI_prefix(unit.exponent)) {
       prefix <- exponent2prefix(unit.exponent)
-      bquote(.(label.text)~italic(f)~(plain(.(prefix))*plain(Hz)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(f)~(plain(.(prefix))*plain(Hz)))
+      } else {
+        bquote(.(label.text)~(plain(.(prefix))*plain(Hz)))
+      }
     } else {
-      bquote(.(label.text)~italic(f)~(10^{.(unit.exponent)}~plain(Hz)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(f)~(10^{.(unit.exponent)}~plain(Hz)))
+      } else {
+        bquote(.(label.text)~(10^{.(unit.exponent)}~plain(Hz)))
+      }
     }
   } else if (format == "R.character" &&
              has_SI_prefix(unit.exponent)) {
@@ -190,7 +232,12 @@ w_frequency_label <- function(unit.exponent = 9,
 w_energy_eV_label <- function(unit.exponent = 0,
                            format = getOption("photobiology.math",
                                               default = "R.expression"),
-                           label.text = axis_labels()[["energy"]]) {
+                           label.text = axis_labels()[["energy"]],
+                           axis.symbols = getOption("ggspectra.axis.symbols",
+                                                   default = TRUE)) {
+  if (!axis.symbols) {
+    label.text <- gsub(",$", "", label.text)
+  }
   if (tolower(format) == "latex") {
     if (has_SI_prefix(unit.exponent)) {
       paste(label.text, " $E$ (",
@@ -204,9 +251,17 @@ w_energy_eV_label <- function(unit.exponent = 0,
   } else if (format %in% c("R.expression")) {
     if (has_SI_prefix(unit.exponent)) {
       prefix <- exponent2prefix(unit.exponent)
-      bquote(.(label.text)~italic(E)~(plain(.(prefix))*plain(eV)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(E)~(plain(.(prefix))*plain(eV)))
+      } else {
+        bquote(.(label.text)~(plain(.(prefix))*plain(eV)))
+      }
     } else {
-      bquote(.(label.text)~italic(E)~(10^{.(unit.exponent)}~plain(eV)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(E)~(10^{.(unit.exponent)}~plain(eV)))
+      } else {
+        bquote(.(label.text)~(10^{.(unit.exponent)}~plain(eV)))
+      }
     }
   } else if (format == "R.character" &&
              has_SI_prefix(unit.exponent)) {
@@ -225,9 +280,14 @@ w_energy_eV_label <- function(unit.exponent = 0,
 #' @export
 #'
 w_energy_J_label <- function(unit.exponent = -18,
-                              format = getOption("photobiology.math",
-                                                 default = "R.expression"),
-                              label.text = axis_labels()[["energy"]]) {
+                             format = getOption("photobiology.math",
+                                                default = "R.expression"),
+                             label.text = axis_labels()[["energy"]],
+                             axis.symbols = getOption("ggspectra.axis.symbols",
+                                                     default = TRUE)) {
+  if (!axis.symbols) {
+    label.text <- gsub(",$", "", label.text)
+  }
   if (tolower(format) == "latex") {
     if (has_SI_prefix(unit.exponent)) {
       paste(label.text, " $E$ (",
@@ -241,9 +301,17 @@ w_energy_J_label <- function(unit.exponent = -18,
   } else if (format %in% c("R.expression")) {
     if (has_SI_prefix(unit.exponent)) {
       prefix <- exponent2prefix(unit.exponent)
-      bquote(.(label.text)~italic(E)~(plain(.(prefix))*plain(J)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(E)~(plain(.(prefix))*plain(J)))
+      } else {
+        bquote(.(label.text)~(plain(.(prefix))*plain(J)))
+      }
     } else {
-      bquote(.(label.text)~italic(E)~(10^{.(unit.exponent)}~plain(J)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(E)~(10^{.(unit.exponent)}~plain(J)))
+      } else {
+        bquote(.(label.text)~(10^{.(unit.exponent)}~plain(J)))
+      }
     }
   } else if (format == "R.character" &&
              has_SI_prefix(unit.exponent)) {
@@ -275,6 +343,8 @@ w_energy_J_label <- function(unit.exponent = -18,
 #' @param unit.exponent integer The exponent on base 10 of the scale multiplier
 #'   used for the axis labels, e.g., 3 for \eqn{10^3} or \eqn{k}.
 #' @param label.text character Textual portion of the labels.
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #'
 #' @export
 #'
@@ -336,10 +406,13 @@ w_energy_J_label <- function(unit.exponent = -18,
 #'
 sec_axis_w_number <-
   function(unit.exponent = -6,
-           label.text = axis_labels()[["w.number"]]) {
+           label.text = axis_labels()[["w.number"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE)) {
     ggplot2::sec_axis(trans = ~photobiology::wl2wavenumber(., unit.exponent),
                       name = w_number_label(unit.exponent = unit.exponent,
-                                            label.text = label.text),
+                                            label.text = label.text,
+                                            axis.symbols = axis.symbols),
                       breaks = scales::pretty_breaks(n = 7))
   }
 
@@ -349,10 +422,13 @@ sec_axis_w_number <-
 #'
 sec_axis_w_frequency <-
   function(unit.exponent = 12,
-           label.text = axis_labels()[["freq"]]) {
+           label.text = axis_labels()[["freq"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE)) {
     ggplot2::sec_axis(trans = ~photobiology::wl2frequency(., unit.exponent),
                       name = w_frequency_label(unit.exponent = unit.exponent,
-                                               label.text = label.text),
+                                               label.text = label.text,
+                                               axis.symbols = axis.symbols),
                       breaks = scales::pretty_breaks(n = 7)
     )
   }
@@ -363,10 +439,13 @@ sec_axis_w_frequency <-
 #'
 sec_axis_energy_eV <-
   function(unit.exponent = 0,
-           label.text = axis_labels()[["energy"]]) {
+           label.text = axis_labels()[["energy"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE)) {
     ggplot2::sec_axis(trans = ~photobiology::wl2energy(., unit.exponent, unit = "eV"),
                       name = w_energy_eV_label(unit.exponent = unit.exponent,
-                                               label.text = label.text),
+                                               label.text = label.text,
+                                               axis.symbols = axis.symbols),
                       breaks = scales::pretty_breaks(n = 8)
     )
   }
@@ -377,10 +456,13 @@ sec_axis_energy_eV <-
 #'
 sec_axis_energy_J <-
   function(unit.exponent = -18,
-           label.text = axis_labels()[["energy"]]) {
+           label.text = axis_labels()[["energy"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE)) {
     ggplot2::sec_axis(trans = ~photobiology::wl2energy(., unit.exponent, unit = "joule"),
                       name = w_energy_J_label(unit.exponent = unit.exponent,
-                                               label.text = label.text),
+                                               label.text = label.text,
+                                              axis.symbols = axis.symbols),
                       breaks = scales::pretty_breaks(n = 8)
     )
   }
@@ -391,10 +473,13 @@ sec_axis_energy_J <-
 #'
 sec_axis_wl <-
   function(unit.exponent = -9,
-           label.text = axis_labels()[["w.length"]]) {
+           label.text = axis_labels()[["w.length"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE)) {
     ggplot2::sec_axis(trans = function(x) {x / 10^(9 + unit.exponent)},
                       name = w_length_label(unit.exponent = unit.exponent,
-                                            label.text = label.text),
+                                            label.text = label.text,
+                                            axis.symbols = axis.symbols),
                       breaks = scales::pretty_breaks(n = 7)
     )
   }
@@ -415,6 +500,8 @@ sec_axis_wl <-
 #' @param labels The tick labels or a function to generate them from the tick
 #'   positions.
 #' @param label.text character Textual portion of the labels.
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #' @param ... other named arguments passed to \code{scale_y_continuous}
 #'
 #' @note This function only alters two default arguments, please, see
@@ -443,10 +530,13 @@ sec_axis_wl <-
 scale_x_wl_continuous <-
   function(unit.exponent = -9,
            name = w_length_label(unit.exponent = unit.exponent,
-                                 label.text = label.text),
+                                 label.text = label.text,
+                                 axis.symbols= axis.symbols),
            breaks = scales::pretty_breaks(n = 7),
            labels = SI_pl_format(exponent = unit.exponent + 9),
            label.text = axis_labels()[["w.length"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_x_continuous(name = name,
                        breaks = breaks,
@@ -473,6 +563,8 @@ scale_x_wl_continuous <-
 #' @param labels The tick labels or a function to generate them from the tick
 #'   positions.
 #' @param label.text character Textual portion of the labels.
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #' @param ... other named arguments passed to \code{scale_y_continuous}
 #'
 #' @note This function only alters two default arguments, please, see
@@ -493,10 +585,13 @@ scale_x_wl_continuous <-
 scale_x_wavenumber_continuous <-
   function(unit.exponent = -6,
            name = w_number_label(unit.exponent = unit.exponent,
-                                 label.text = label.text),
+                                 label.text = label.text,
+                                 axis.symbols = axis.symbols),
            breaks = scales::pretty_breaks(n = 7),
            labels = SI_pl_format(exponent = -unit.exponent),
            label.text = axis_labels()[["w.number"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_x_continuous(name = name,
                        breaks = breaks,
@@ -523,6 +618,8 @@ scale_x_wavenumber_continuous <-
 #' @param labels The tick labels or a function to generate them from the tick
 #'   positions.
 #' @param label.text character Textual portion of the labels.
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #' @param ... other named arguments passed to \code{scale_y_continuous}
 #'
 #' @note This function only alters two default arguments, please, see
@@ -543,10 +640,13 @@ scale_x_wavenumber_continuous <-
 scale_x_frequency_continuous <-
   function(unit.exponent = 12,
            name = w_frequency_label(unit.exponent = unit.exponent,
-                                    label.text = label.text),
+                                    label.text = label.text,
+                                    axis.symbols = axis.symbols),
            breaks = scales::pretty_breaks(n = 7),
            labels = SI_pl_format(exponent = unit.exponent),
            label.text = axis_labels()[["freq"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_x_continuous(name = name,
                        breaks = breaks,
@@ -573,6 +673,8 @@ scale_x_frequency_continuous <-
 #' @param labels The tick labels or a function to generate them from the tick
 #'   positions.
 #' @param label.text character Textual portion of the labels.
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #' @param ... other named arguments passed to \code{scale_y_continuous}
 #'
 #' @note This function only alters two default arguments, please, see
@@ -601,10 +703,13 @@ scale_x_frequency_continuous <-
 scale_x_energy_eV_continuous <-
   function(unit.exponent = 0,
            name = w_energy_eV_label(unit.exponent = unit.exponent,
-                                 label.text = label.text),
+                                    label.text = label.text,
+                                    axis.symbols = axis.symbols),
            breaks = scales::pretty_breaks(n = 7),
            labels = SI_pl_format(exponent = unit.exponent),
            label.text = axis_labels()[["energy"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_x_continuous(name = name,
                        breaks = breaks,
@@ -619,10 +724,13 @@ scale_x_energy_eV_continuous <-
 scale_x_energy_J_continuous <-
   function(unit.exponent = -18,
            name = w_energy_J_label(unit.exponent = unit.exponent,
-                                    label.text = label.text),
+                                   label.text = label.text,
+                                   axis.symbols = axis.symbols),
            breaks = scales::pretty_breaks(n = 7),
            labels = SI_pl_format(exponent = unit.exponent),
            label.text = axis_labels()[["energy"]],
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_x_continuous(name = name,
                        breaks = breaks,
